# Usage

To see a list of available commands run:

```
twitch-dl --help
```

And to see description and all arguments for a given command run:

```
twitch-dl <command> --help
```

## Commands

Click on a command to see it's documentation.

|                                      |                                 |
|------------------------------------- | ------------------------------- |
| [`videos`](commands/videos.html)     | List videos from a channel.     |
| [`clips`](commands/clips.html)       | List clips from a channel.      |
| [`download`](commands/download.html) | Download a video or clip.       |
| [`info`](commands/info.html)         | Print info for a video or clip. |
